summaryrefslogtreecommitdiff
path: root/inc/FSclAddressbook.h
diff options
context:
space:
mode:
authorhs321.lee <hs321.lee@samsung.com>2013-03-18 11:22:33 +0900
committerhs321.lee <hs321.lee@samsung.com>2013-03-18 11:22:33 +0900
commitca32e33cd472d0a120894085ceac56397e24c9ce (patch)
tree71f79b38cecc4d59d515ff9562dcb0da2f41a69f /inc/FSclAddressbook.h
parent5e755d91d8b859a71c012556f497f1b4a9d7b08b (diff)
downloadsocial-ca32e33cd472d0a120894085ceac56397e24c9ce.tar.gz
social-ca32e33cd472d0a120894085ceac56397e24c9ce.tar.bz2
social-ca32e33cd472d0a120894085ceac56397e24c9ce.zip
Master to tizen_2.1
Change-Id: I4288529d24e61cc4088f0537c664f8377cb48b96 Signed-off-by: hs321.lee <hs321.lee@samsung.com>
Diffstat (limited to 'inc/FSclAddressbook.h')
-rw-r--r--inc/FSclAddressbook.h145
1 files changed, 124 insertions, 21 deletions
diff --git a/inc/FSclAddressbook.h b/inc/FSclAddressbook.h
index 3e7a9bf..90b0de5 100644
--- a/inc/FSclAddressbook.h
+++ b/inc/FSclAddressbook.h
@@ -46,6 +46,7 @@ class Contact;
class UserProfile;
class IRecordEventListener;
class IAddressbookEventListener;
+class IAddressbookChangeEventListener;
class IRecordEventListener;
/**
@@ -61,11 +62,6 @@ class IRecordEventListener;
*
* For more information on the class features, see <a href="../org.tizen.native.appprogramming/html/guide/social/addressbook_namespace.htm">Address Book</a>.
*
- * The following diagram illustrates the relationships between %Addressbook and related classes.
- *
- * @image html social_addressbook_classdiagram.png
- *
- *
* The following example demonstrates how to use the %Addressbook class to create the categories and add contacts to them.
*
* @code
@@ -316,6 +312,10 @@ public:
* The listener is called when a contact or a category has been changed.
* To reset the event listener, @c null must be passed.
*
+ * @brief <i> [Deprecated] </i>
+ * @deprecated This method and IAddressbookEventListener are deprecated. Instead of using this method, use SetAddressbookChangeEventListener()
+ * and IAddressbookChangeEventListener.
+ *
* @since 2.0
* @privlevel public
* @privilege http://tizen.org/privilege/contact.read
@@ -328,6 +328,22 @@ public:
*/
result SetEventListener(IAddressbookEventListener* pListener);
+ /**
+ * Sets addressbook change event listener. @n
+ * The listener is called when a contact or a category has been changed.
+ * To reset the event listener, @c null must be passed.
+ *
+ * @since 2.1
+ * @privlevel public
+ * @privilege http://tizen.org/privilege/contact.read
+ *
+ * @return An error code
+ * @param[in] pListener The event listener
+ * @exception E_SUCCESS The method is successful.
+ * @exception E_PRIVILEGE_DENIED The application does not have the privilege to call this method.
+ * @exception E_SYSTEM The method cannot proceed due to a severe system error
+ */
+ result SetAddressbookChangeEventListener(IAddressbookChangeEventListener* pListener);
/**
* Adds a contact to the address book. @n
@@ -861,6 +877,9 @@ public:
/**
* Gets the change information of the contacts that have been changed after the specified change version. @n
*
+ * @brief <i> [Deprecated] </i>
+ * @deprecated This method is deprecated. Instead of using this method, use GetChangedContactInfoListAfterN().
+ *
* @since 2.0
* @privlevel public
* @privilege http://tizen.org/privilege/contact.read
@@ -899,30 +918,114 @@ public:
Tizen::Base::Collection::IList* GetChangedContactsAfterN(int version, int& latestVersion) const;
/**
+ * Gets the change information of the contacts that have been changed after the specified change version. @n
+ *
+ * @since 2.1
+ * @privlevel public
+ * @privilege http://tizen.org/privilege/contact.read
+ *
+ * @return A list of contact change information, @n
+ * else an empty list if there is no changed contact or @c null if an exception occurs (@ref ContactChangeInfo list)
+ * @param[in] version The change version
+ * @param[out] latestVersion The latest change version among the changed contacts
+ * @exception E_SUCCESS The method is successful.
+ * @exception E_PRIVILEGE_DENIED The application does not have the privilege to call this method.
+ * @exception E_INVALID_ARG The specified @c version is invalid.
+ * @exception E_SYSTEM The method cannot proceed due to a severe system error
+ * @remarks The specific error code can be accessed using the GetLastResult() method.
+ * @see GetLatestVersion()
+ *
+ * The following example demonstrates how to use the %GetChangedContactInfoListAfterN() method.
+ * @code
+ * void
+ * MyApplication::GetChangedContacts(void)
+ * {
+ * IList* pChangedContacts = __pAddressbook->GetChangedContactInfoListAfterN (__version, __version);
+ *
+ * IEnumerator* pEnum = pChangedContacts->GetEnumeratorN();
+ * while (pEnum->MoveNext() == E_SUCCESS)
+ * {
+ * ContactChangeInfo* pInfo = (ContactChangeInfo*) pEnum->GetCurrent();
+ *
+ * AppLog("Contact changed: type(%d), id(%d), version(%d)", pInfo->GetChangeType(), pInfo->GetContctId(), pInfo->GetVersion());
+ * }
+ * delete pEnum;
+ * pChangedContacts->RemoveAll(true);
+ * delete pChangedContacts;
+ * }
+ * @endcode
+ */
+ Tizen::Base::Collection::IList* GetChangedContactInfoListN(int version, int& latestVersion) const;
+
+ /**
+ * Gets the change information of the categories that have been changed after the specified version.
+ *
+ * @brief <i> [Deprecated] </i>
+ * @deprecated This method is deprecated. Instead of using this method, use GetChangedCategoryInfoListAfterN().
+ *
+ * @since 2.0
+ * @privlevel public
+ * @privilege http://tizen.org/privilege/contact.read
+ *
+ * @return A list of category change information, @n
+ * else an empty list if there is no changed category or @c null if an exception occurs (@ref CategoryChangeInfo list)
+ *
+ * @param[in] version The change version
+ * @param[out] latestVersion The latest change version among the changed categories
+ * @exception E_SUCCESS The method is successful.
+ * @exception E_PRIVILEGE_DENIED The application does not have the privilege to call this method.
+ * @exception E_INVALID_ARG The specified @c version is invalid.
+ * @exception E_SYSTEM A system error has occurred.
+ * @remarks The specific error code can be accessed using the GetLastResult() method.
+ * @see GetLatestVersion()
+ *
+ * The following example demonstrates how to use the %GetChangedCategoriesAfterN() method.
+ * @code
+ * void
+ * MyApplication::GetChangedCategories(void)
+ * {
+ * IList* pChangedCategories = __pAddressbook->GetChangedCategoriesAfterN(__version, __version);
+ *
+ * IEnumerator* pEnum = pChangedCategories->GetEnumeratorN();
+ * while (pEnum->MoveNext() == E_SUCCESS)
+ * {
+ * CategoryChangeInfo* pInfo = (CategoryChangeInfo*) pEnum->GetCurrent();
+ *
+ * AppLog("Category changed: type(%d), id(%d), version(%d)", pInfo->GetChangeType(), pInfo->GetCategoryId(), pInfo->GetVersion());
+ * }
+ * delete pEnum;
+ * pChangedCategories->RemoveAll(true);
+ * delete pChangedCategories;
+ * }
+ * @endcode
+ */
+ Tizen::Base::Collection::IList* GetChangedCategoriesAfterN(int version, int& latestVersion) const;
+
+ /**
* Gets the change information of the categories that have been changed after the specified version.
*
- * @since 2.0
- * @privlevel public
- * @privilege http://tizen.org/privilege/contact.read
+ * @since 2.1
+ * @privlevel public
+ * @privilege http://tizen.org/privilege/contact.read
*
- * @return A list of category change information, @n
- * else an empty list if there is no changed category or @c null if an exception occurs (@ref CategoryChangeInfo list)
- *
- * @param[in] version The change version
- * @param[out] latestVersion The latest change version among the changed categories
- * @exception E_SUCCESS The method is successful.
- * @exception E_PRIVILEGE_DENIED The application does not have the privilege to call this method.
- * @exception E_INVALID_ARG The specified @c version is invalid.
- * @exception E_SYSTEM A system error has occurred.
- * @remarks The specific error code can be accessed using the GetLastResult() method.
+ * @return A list of category change information, @n
+ * else an empty list if there is no changed category or @c null if an exception occurs (@ref CategoryChangeInfo list)
+ *
+ * @param[in] version The change version
+ * @param[out] latestVersion The latest change version among the changed categories
+ * @exception E_SUCCESS The method is successful.
+ * @exception E_PRIVILEGE_DENIED The application does not have the privilege to call this method.
+ * @exception E_INVALID_ARG The specified @c version is invalid.
+ * @exception E_SYSTEM The method cannot proceed due to a severe system error
+ * @remarks The specific error code can be accessed using the GetLastResult() method.
* @see GetLatestVersion()
*
* The following example demonstrates how to use the %GetChangedCategoriesAfterN() method.
* @code
* void
* MyApplication::GetChangedCategories(void)
* {
- * IList* pChangedCategories = __pAddressbook->GetChangedCategoriesAfterN(__version, __version);
+ * IList* pChangedCategories = __pAddressbook->GetChangedCategoryInfoAfterN(__version, __version);
*
* IEnumerator* pEnum = pChangedCategories->GetEnumeratorN();
* while (pEnum->MoveNext() == E_SUCCESS)
@@ -937,7 +1040,7 @@ public:
* }
* @endcode
*/
- Tizen::Base::Collection::IList* GetChangedCategoriesAfterN(int version, int& latestVersion) const;
+ Tizen::Base::Collection::IList* GetChangedCategoryInfoListN(int version, int& latestVersion) const;
/**
* Sets the user profile of this addressbook. To remove the user profile, @c null must be passed.
@@ -899,30 +918,114 @@ public:
* @see GetLatestVersion()
*
- * The following example demonstrates how to use the %GetChangedCategoriesAfterN() method.
+ * The following example demonstrates how to use the %GetChangedCategoryInfoListAfterN() method.
* @code
* void